Credentials class

A class describing OAuth credentials except for client credential

Constructors

Credentials(String _token, String _tokenSecret)
Credentials.fromJSON(String jstr)
factory
Credentials.fromMap(Map<String, String> parameters)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
no setter
tokenSecret → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited